@@ -1,8 +1,5 @@
 no warnings;
 
-use DBI;
-
-use Data::Dumper;
 #use DBIx::ModelUpdate;
 
 ################################################################################
